@@ -876,6 +876,10 @@ class Response:
 
         self._request: typing.Optional[Request] = request
 
+        # When allow_redirects=False and a redirect is received,
+        # the client will set `response.next_request`.
+        self.next_request: typing.Optional[Request] = None
+
         self.call_next: typing.Optional[typing.Callable] = None
 
         self.ext = {} if ext is None else ext
